@@ -18,7 +18,11 @@ log = get_logger(NAME)
 from .configuration import *
 from .logger import *
 from .metadata import *
-from ._vendor import releases, toml
+from ._vendor import color_print, releases, toml
+
+# This is a hack to allow doing from sdsstools.color_print import color_text
+# which some code already does.
+sys.modules['sdsstools.color_print'] = color_print
 
 # Allow to access releases as sdsstools.releases. This is important to
 # define it as an extension in Sphinx.
